"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var crypto_1 = __importDefault(require("crypto"));
var uuid_1 = __importDefault(require("uuid"));
/**
 * Shortcut for generating a v4 uuid
 */
function uuid() {
    return uuid_1["default"].v4();
}
exports.uuid = uuid;
/**
 * Generate a hex digest from an input
 * @param seed the value to hash
 * @param length truncate the output to this length
 */
function hash(seed, length) {
    if (length === void 0) { length = 64; }
    seed = seed || Math.random();
    return crypto_1["default"].createHash('sha256')
        .update(seed.toString(), 'utf8')
        .digest('hex')
        .substring(0, length);
}
exports.hash = hash;
/**
 * Convert a sentence to a URL hash with an optional random hash on the end
 * @param string the sentence to slugify
 * @param hashLength add some a hash of this length to the end
 */
function slug(string, hashLength) {
    if (hashLength === void 0) { hashLength = 0; }
    var slug = string
        .toLowerCase()
        .replace(/[\'\!\"\&\%]/g, '')
        .replace(/[^a-z0-9]/g, '-')
        .replace(/\-+/g, '-')
        .replace(/(^\-|\-$)/, '');
    if (hashLength > 0) {
        slug += '-' + hash(null, hashLength);
    }
    return slug;
}
exports.slug = slug;
/**
 * Get a weighted random value from an array
 * @param array an array of values and weights
 * @param weightProperty the property to use for weighting
 */
function weightedRandomValue(array, weightProperty) {
    if (weightProperty === void 0) { weightProperty = 'weight'; }
    var weightedArray = [];
    array.forEach(function (item) {
        for (var i = 0; i < parseInt(item[weightProperty], 10); i++) {
            weightedArray.push(item);
        }
    });
    return weightedArray[Math.floor(Math.random() * weightedArray.length)];
}
exports.weightedRandomValue = weightedRandomValue;
exports["default"] = {
    uuid: uuid,
    hash: hash,
    slug: slug,
    weightedRandomValue: weightedRandomValue
};
